Class: Aws::CodeGuruReviewer::Types::AssociateRepositoryRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CodeGuruReviewer::Types::AssociateRepositoryRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-codegurureviewer/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_request_token ⇒ String
Amazon CodeGuru Reviewer uses this value to prevent the accidental creation of duplicate repository associations if there are failures and retries.
-
#kms_key_details ⇒ Types::KMSKeyDetails
A
KMSKeyDetailsobject that contains:. -
#repository ⇒ Types::Repository
The repository to associate.
-
#tags ⇒ Hash<String,String>
An array of key-value pairs used to tag an associated repository.
Instance Attribute Details
#client_request_token ⇒ String
Amazon CodeGuru Reviewer uses this value to prevent the accidental creation of duplicate repository associations if there are failures and retries.
A suitable default value is auto-generated. You should normally not need to pass this option.
65 66 67 68 69 70 71 72 |
# File 'lib/aws-sdk-codegurureviewer/types.rb', line 65 class AssociateRepositoryRequest < Struct.new( :repository, :client_request_token, :tags, :kms_key_details) SENSITIVE = [] include Aws::Structure end |
#kms_key_details ⇒ Types::KMSKeyDetails
A KMSKeyDetails object that contains:
-
The encryption option for this repository association. It is either owned by Amazon Web Services Key Management Service (KMS) (
AWS_OWNED_CMK) or customer managed (CUSTOMER_MANAGED_CMK). -
The ID of the Amazon Web Services KMS key that is associated with this repository association.
65 66 67 68 69 70 71 72 |
# File 'lib/aws-sdk-codegurureviewer/types.rb', line 65 class AssociateRepositoryRequest < Struct.new( :repository, :client_request_token, :tags, :kms_key_details) SENSITIVE = [] include Aws::Structure end |
#repository ⇒ Types::Repository
The repository to associate.
65 66 67 68 69 70 71 72 |
# File 'lib/aws-sdk-codegurureviewer/types.rb', line 65 class AssociateRepositoryRequest < Struct.new( :repository, :client_request_token, :tags, :kms_key_details) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
An array of key-value pairs used to tag an associated repository. A tag is a custom attribute label with two parts:
-
A tag key (for example,
CostCenter,Environment,Project, orSecret). Tag keys are case sensitive. -
An optional field known as a tag value (for example,
111122223333,Production, or a team name). Omitting the tag value is the same as using an empty string. Like tag keys, tag values are case sensitive.
65 66 67 68 69 70 71 72 |
# File 'lib/aws-sdk-codegurureviewer/types.rb', line 65 class AssociateRepositoryRequest < Struct.new( :repository, :client_request_token, :tags, :kms_key_details) SENSITIVE = [] include Aws::Structure end |