Class: Aws::CodeGuruReviewer::Types::BranchDiffSourceCodeType
- Inherits:
-
Struct
- Object
- Struct
- Aws::CodeGuruReviewer::Types::BranchDiffSourceCodeType
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-codegurureviewer/types.rb
Overview
Note:
When making an API call, you may pass BranchDiffSourceCodeType data as a hash:
{
source_branch_name: "BranchName", # required
destination_branch_name: "BranchName", # required
}
A type of [ SourceCodeType ][1] that specifies a code diff between a source and destination branch in an associated repository.
[1]: docs.aws.amazon.com/codeguru/latest/reviewer-api/API_SourceCodeType
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#destination_branch_name ⇒ String
The destination branch for a diff in an associated repository.
-
#source_branch_name ⇒ String
The source branch for a diff in an associated repository.
Instance Attribute Details
#destination_branch_name ⇒ String
The destination branch for a diff in an associated repository.
158 159 160 161 162 163 |
# File 'lib/aws-sdk-codegurureviewer/types.rb', line 158 class BranchDiffSourceCodeType < Struct.new( :source_branch_name, :destination_branch_name) SENSITIVE = [] include Aws::Structure end |
#source_branch_name ⇒ String
The source branch for a diff in an associated repository.
158 159 160 161 162 163 |
# File 'lib/aws-sdk-codegurureviewer/types.rb', line 158 class BranchDiffSourceCodeType < Struct.new( :source_branch_name, :destination_branch_name) SENSITIVE = [] include Aws::Structure end |