Class: Aws::CodeGuruReviewer::Types::CreateCodeReviewRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CodeGuruReviewer::Types::CreateCodeReviewRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-codegurureviewer/types.rb
Overview
When making an API call, you may pass CreateCodeReviewRequest data as a hash:
{
name: "CodeReviewName", # required
repository_association_arn: "AssociationArn", # required
type: { # required
repository_analysis: { # required
repository_head: {
branch_name: "BranchName", # required
},
source_code_type: {
commit_diff: {
source_commit: "CommitId",
destination_commit: "CommitId",
merge_base_commit: "CommitId",
},
repository_head: {
branch_name: "BranchName", # required
},
branch_diff: {
source_branch_name: "BranchName", # required
destination_branch_name: "BranchName", # required
},
s3_bucket_repository: {
name: "Name", # required
details: {
bucket_name: "S3BucketName",
code_artifacts: {
source_code_artifacts_object_key: "SourceCodeArtifactsObjectKey", # required
build_artifacts_object_key: "BuildArtifactsObjectKey",
},
},
},
request_metadata: {
request_id: "RequestId",
requester: "Requester",
event_info: {
name: "EventName",
state: "EventState",
},
vendor_name: "GitHub", # accepts GitHub, GitLab, NativeS3
},
},
},
analysis_types: ["Security"], # accepts Security, CodeQuality
},
client_request_token: "ClientRequestToken",
}Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_request_token ⇒ String
Amazon CodeGuru Reviewer uses this value to prevent the accidental creation of duplicate code reviews if there are failures and retries.
-
#name ⇒ String
The name of the code review.
-
#repository_association_arn ⇒ String
The Amazon Resource Name (ARN) of the [
RepositoryAssociation][1] object. -
#type ⇒ Types::CodeReviewType
The type of code review to create.
Instance Attribute Details
#client_request_token ⇒ String
Amazon CodeGuru Reviewer uses this value to prevent the accidental creation of duplicate code reviews if there are failures and retries.
A suitable default value is auto-generated. You should normally not need to pass this option.
669 670 671 672 673 674 675 676 |
# File 'lib/aws-sdk-codegurureviewer/types.rb', line 669 class CreateCodeReviewRequest < Struct.new( :name, :repository_association_arn, :type, :client_request_token) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the code review. The name of each code review in your AWS account must be unique.
669 670 671 672 673 674 675 676 |
# File 'lib/aws-sdk-codegurureviewer/types.rb', line 669 class CreateCodeReviewRequest < Struct.new( :name, :repository_association_arn, :type, :client_request_token) SENSITIVE = [] include Aws::Structure end |
#repository_association_arn ⇒ String
The Amazon Resource Name (ARN) of the RepositoryAssociation
object. You can retrieve this ARN by calling
ListRepositoryAssociations .
A code review can only be created on an associated repository. This is the ARN of the associated repository.
669 670 671 672 673 674 675 676 |
# File 'lib/aws-sdk-codegurureviewer/types.rb', line 669 class CreateCodeReviewRequest < Struct.new( :name, :repository_association_arn, :type, :client_request_token) SENSITIVE = [] include Aws::Structure end |
#type ⇒ Types::CodeReviewType
The type of code review to create. This is specified using a
CodeReviewType object. You can create a code review only of
type RepositoryAnalysis.
669 670 671 672 673 674 675 676 |
# File 'lib/aws-sdk-codegurureviewer/types.rb', line 669 class CreateCodeReviewRequest < Struct.new( :name, :repository_association_arn, :type, :client_request_token) SENSITIVE = [] include Aws::Structure end |