Class: Aws::CodeGuruReviewer::Types::RepositoryHeadSourceCodeType
- Inherits:
-
Struct
- Object
- Struct
- Aws::CodeGuruReviewer::Types::RepositoryHeadSourceCodeType
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-codegurureviewer/types.rb
Overview
Note:
When making an API call, you may pass RepositoryHeadSourceCodeType data as a hash:
{
branch_name: "BranchName", # required
}
A [ SourceCodeType ][1] that specifies the tip of a branch in an associated repository.
[1]: docs.aws.amazon.com/codeguru/latest/reviewer-api/API_SourceCodeType
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#branch_name ⇒ String
The name of the branch in an associated repository.
Instance Attribute Details
#branch_name ⇒ String
The name of the branch in an associated repository. The RepositoryHeadSourceCodeType specifies the tip of this branch.
2013 2014 2015 2016 2017 |
# File 'lib/aws-sdk-codegurureviewer/types.rb', line 2013 class RepositoryHeadSourceCodeType < Struct.new( :branch_name) SENSITIVE = [] include Aws::Structure end |