Class: Aws::CodeGuruReviewer::Types::SourceCodeType
- Inherits:
-
Struct
- Object
- Struct
- Aws::CodeGuruReviewer::Types::SourceCodeType
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-codegurureviewer/types.rb
Overview
Specifies the source code that is analyzed in a code review.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#branch_diff ⇒ Types::BranchDiffSourceCodeType
A type of [SourceCodeType][1] that specifies a source branch name and a destination branch name in an associated repository.
-
#commit_diff ⇒ Types::CommitDiffSourceCodeType
A [SourceCodeType][1] that specifies a commit diff created by a pull request on an associated repository.
-
#repository_head ⇒ Types::RepositoryHeadSourceCodeType
A [SourceCodeType][1] that specifies the tip of a branch in an associated repository.
-
#request_metadata ⇒ Types::RequestMetadata
Metadata that is associated with a code review.
-
#s3_bucket_repository ⇒ Types::S3BucketRepository
Information about an associated repository in an S3 bucket that includes its name and an
S3RepositoryDetailsobject.
Instance Attribute Details
#branch_diff ⇒ Types::BranchDiffSourceCodeType
A type of [SourceCodeType][1] that specifies a source branch name and a destination branch name in an associated repository.
[1]: docs.aws.amazon.com/codeguru/latest/reviewer-api/API_SourceCodeType
1944 1945 1946 1947 1948 1949 1950 1951 1952 |
# File 'lib/aws-sdk-codegurureviewer/types.rb', line 1944 class SourceCodeType < Struct.new( :commit_diff, :repository_head, :branch_diff, :s3_bucket_repository, :request_metadata) SENSITIVE = [] include Aws::Structure end |
#commit_diff ⇒ Types::CommitDiffSourceCodeType
A [SourceCodeType][1] that specifies a commit diff created by a pull request on an associated repository.
[1]: docs.aws.amazon.com/codeguru/latest/reviewer-api/API_SourceCodeType
1944 1945 1946 1947 1948 1949 1950 1951 1952 |
# File 'lib/aws-sdk-codegurureviewer/types.rb', line 1944 class SourceCodeType < Struct.new( :commit_diff, :repository_head, :branch_diff, :s3_bucket_repository, :request_metadata) SENSITIVE = [] include Aws::Structure end |
#repository_head ⇒ Types::RepositoryHeadSourceCodeType
A [SourceCodeType][1] that specifies the tip of a branch in an associated repository.
[1]: docs.aws.amazon.com/codeguru/latest/reviewer-api/API_SourceCodeType
1944 1945 1946 1947 1948 1949 1950 1951 1952 |
# File 'lib/aws-sdk-codegurureviewer/types.rb', line 1944 class SourceCodeType < Struct.new( :commit_diff, :repository_head, :branch_diff, :s3_bucket_repository, :request_metadata) SENSITIVE = [] include Aws::Structure end |
#request_metadata ⇒ Types::RequestMetadata
Metadata that is associated with a code review. This applies to any type of code review supported by CodeGuru Reviewer. The RequestMetadaa field captures any event metadata. For example, it might capture metadata associated with an event trigger, such as a push or a pull request.
1944 1945 1946 1947 1948 1949 1950 1951 1952 |
# File 'lib/aws-sdk-codegurureviewer/types.rb', line 1944 class SourceCodeType < Struct.new( :commit_diff, :repository_head, :branch_diff, :s3_bucket_repository, :request_metadata) SENSITIVE = [] include Aws::Structure end |
#s3_bucket_repository ⇒ Types::S3BucketRepository
Information about an associated repository in an S3 bucket that includes its name and an S3RepositoryDetails object. The S3RepositoryDetails object includes the name of an S3 bucket, an S3 key for a source code .zip file, and an S3 key for a build artifacts .zip file. S3BucketRepository is required in
- SourceCodeType][1
-
for
S3BucketRepositorybased code reviews.
[1]: docs.aws.amazon.com/codeguru/latest/reviewer-api/API_SourceCodeType
1944 1945 1946 1947 1948 1949 1950 1951 1952 |
# File 'lib/aws-sdk-codegurureviewer/types.rb', line 1944 class SourceCodeType < Struct.new( :commit_diff, :repository_head, :branch_diff, :s3_bucket_repository, :request_metadata) SENSITIVE = [] include Aws::Structure end |