Class: Aws::CodeGuruReviewer::Waiters::RepositoryAssociationSucceeded
- Inherits:
-
Object
- Object
- Aws::CodeGuruReviewer::Waiters::RepositoryAssociationSucceeded
- Defined in:
- lib/aws-sdk-codegurureviewer/waiters.rb,
sig/waiters.rbs
Overview
Wait until a repository association is complete.
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ RepositoryAssociationSucceeded
constructor
A new instance of RepositoryAssociationSucceeded.
-
#wait(params = {}) ⇒ Types::DescribeRepositoryAssociationResponse
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ RepositoryAssociationSucceeded
Returns a new instance of RepositoryAssociationSucceeded.
137 138 |
# File 'lib/aws-sdk-codegurureviewer/waiters.rb', line 137
def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void
|
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
175 176 177 |
# File 'lib/aws-sdk-codegurureviewer/waiters.rb', line 175 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::DescribeRepositoryAssociationResponse
Returns a response object which responds to the following methods:
- #repository_association => Types::RepositoryAssociation
- #tags => Hash<String,String>
170 |
# File 'lib/aws-sdk-codegurureviewer/waiters.rb', line 170
def wait: (
|