Class: Aws::CodeGuruReviewer::Types::CommitDiffSourceCodeType
- Inherits:
-
Struct
- Object
- Struct
- Aws::CodeGuruReviewer::Types::CommitDiffSourceCodeType
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-codegurureviewer/types.rb
Overview
A type of [ SourceCodeType ][1] that specifies the commit diff for a pull request on an associated repository.
[1]: docs.aws.amazon.com/codeguru/latest/reviewer-api/API_SourceCodeType
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#destination_commit ⇒ String
The SHA of the destination commit used to generate a commit diff.
-
#source_commit ⇒ String
The SHA of the source commit used to generate a commit diff.
Instance Attribute Details
#destination_commit ⇒ String
The SHA of the destination commit used to generate a commit diff.
408 409 410 411 412 413 |
# File 'lib/aws-sdk-codegurureviewer/types.rb', line 408 class CommitDiffSourceCodeType < Struct.new( :source_commit, :destination_commit) SENSITIVE = [] include Aws::Structure end |
#source_commit ⇒ String
The SHA of the source commit used to generate a commit diff.
408 409 410 411 412 413 |
# File 'lib/aws-sdk-codegurureviewer/types.rb', line 408 class CommitDiffSourceCodeType < Struct.new( :source_commit, :destination_commit) SENSITIVE = [] include Aws::Structure end |